/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

package uk.co.petertribble.jangle;

import snmp.*;
import java.net.InetAddress;
import javax.swing.*;
import java.awt.event.*;
import java.awt.*;
import java.io.File;
import uk.co.petertribble.jingle.*;

public class SnmpBrowser implements ActionListener {

    private static final String DEFAULT_HOST = "localhost";
    private static final String DEFAULT_COMMUNITY = "public";

    private SnmpResources snr;

    private SnmpTreePanel stp;

    private JMenuItem exitItem;
    private JMenuItem cloneItem;
    private JMenuItem closeItem;
    private JMenuItem helpItem;
    private JMenuItem licenseItem;
    private JFrame jf;

    // delays need to be longer for snmp
    private JRadioButtonMenuItem sleepItem15;
    private JRadioButtonMenuItem sleepItem30;
    private JRadioButtonMenuItem sleepItem60;

    private JTextField jtserver;
    private JTextField jtcomm;
    private JButton jbload;

    public SnmpBrowser() {
	snr = SnmpResources.getInstance();
	jf = new JFrame(snr.getString("BROWSERUI.NAME.TEXT"));
	jf.addWindowListener(new winExit());
	JMenuBar jm = new JMenuBar();

	JMenu jme = new JMenu(snr.getString("FILE.TEXT"));
	jme.setMnemonic(KeyEvent.VK_F);
	cloneItem = new JMenuItem(snr.getString("FILE.NEWBROWSER.TEXT"),
				KeyEvent.VK_B);
	cloneItem.addActionListener(this);
	jme.add(cloneItem);
	closeItem = new JMenuItem(snr.getString("FILE.CLOSEWIN.TEXT"),
				KeyEvent.VK_W);
	closeItem.addActionListener(this);
	jme.add(closeItem);
	exitItem = new JMenuItem(snr.getString("FILE.EXIT.TEXT"),
				KeyEvent.VK_X);
	exitItem.addActionListener(this);
	jme.add(exitItem);

	JingleMultiFrame.register(jf, closeItem);

	JMenu jms = new JMenu(snr.getString("SLEEP.TEXT"));
	sleepItem15 = new JRadioButtonMenuItem(snr.getString("SLEEP.15"));
	sleepItem15.addActionListener(this);
	sleepItem30 = new JRadioButtonMenuItem(snr.getString("SLEEP.30"), true);
	sleepItem30.addActionListener(this);
	sleepItem60 = new JRadioButtonMenuItem(snr.getString("SLEEP.60"));
	sleepItem60.addActionListener(this);
	jms.add(sleepItem15);
	jms.add(sleepItem30);
	jms.add(sleepItem60);

	ButtonGroup sleepGroup = new ButtonGroup();
	sleepGroup.add(sleepItem15);
	sleepGroup.add(sleepItem30);
	sleepGroup.add(sleepItem60);
	JMenu jmh = new JMenu(snr.getString("HELP.TEXT"));
	jmh.setMnemonic(KeyEvent.VK_H);
	helpItem = new JMenuItem(snr.getString("HELP.ABOUT.TEXT")
				+ " jangle", KeyEvent.VK_A);
	helpItem.addActionListener(this);
	jmh.add(helpItem);
	licenseItem = new JMenuItem(snr.getString("HELP.LICENSE.TEXT"),
				KeyEvent.VK_L);
	licenseItem.addActionListener(this);
	jmh.add(licenseItem);

	jm.add(jme);
	jm.add(jms);
	jm.add(jmh);

	jf.setJMenuBar(jm);

	JPanel jp = new JPanel(new BorderLayout());
	jf.setContentPane(jp);

	// a panel for the user to enter the server details.
	JPanel jpq = new JPanel(new FlowLayout());
	// FIXME localize
	// FIXME initial defaults of localhost and public?
	// FIXME snmp version?
	jpq.add(new JLabel("Server:"));
	jtserver = new JTextField(DEFAULT_HOST, 12);
	jpq.add(jtserver);
	jpq.add(new JLabel("Community String:"));
	jtcomm = new JTextField(DEFAULT_COMMUNITY, 12);
	jpq.add(jtcomm);
	jbload = new JButton("Load");
	jbload.addActionListener(this);
	jpq.add(jbload);

	jp.add(jpq, BorderLayout.NORTH);

	stp = new SnmpTreePanel();
	jp.add(stp);

	jf.setSize(840, 640);
	jf.setVisible(true);
    }

    class winExit extends WindowAdapter {
	public void windowClosing(WindowEvent we) {
	    JingleMultiFrame.unregister(jf);
	}
    }

    public void setDelay(int i) {
	stp.setDelay(i);
    }

    public void doload() {
	stp.exploreServer(new SnmpParams(jtserver.getText(), jtcomm.getText()));
    }

    public void actionPerformed(ActionEvent e) {
	if (e.getSource() == cloneItem) {
	    new SnmpBrowser();
	}
	if (e.getSource() == closeItem) {
	    JingleMultiFrame.unregister(jf);
	}
	if (e.getSource() == exitItem) {
	    System.exit(0);
	}
	if (e.getSource() == helpItem) {
	    new JingleInfoFrame(this.getClass().getClassLoader(),
				"help/index.html", "text/html");
	}
	if (e.getSource() == licenseItem) {
	    new JingleInfoFrame(this.getClass().getClassLoader(),
				"help/CDDL.txt", "text/plain");
	}
	if (e.getSource() == sleepItem15) {
	    setDelay(15);
	}
	if (e.getSource() == sleepItem30) {
	    setDelay(30);
	}
	if (e.getSource() == sleepItem60) {
	    setDelay(60);
	}
	if (e.getSource() == jbload) {
	    doload();
	}
    }

    // FIXME pass a server on the command line
    public static void main(String[] args) {
	new SnmpBrowser();
    }
}
