/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

package uk.co.petertribble.jangle;

import java.net.InetAddress;
import snmp.*;
import java.io.IOException;

public class SnmpController {

    private SnmpParams params;
    private SNMPv1CommunicationInterface ifv1;

    public SnmpController(SnmpParams params) {
	this.params = params;
	initialize();
    }

    private void initialize() {
	try {
	    InetAddress hostAddress = InetAddress.getByName(params.getServer());
	    ifv1 =
		new SNMPv1CommunicationInterface(params.getVersion(),
						hostAddress,
						params.getCommunity());
	    // FIXME be specific
	} catch (Exception e) {
	    System.out.println("Controller Initialization failed.");
	    // do summat
	}
    }

    public SNMPv1CommunicationInterface getInterfaceV1() {
	return ifv1;
    }

    public SNMPVarBindList getNextMIBEntry(String s) {
	try {
	    return ifv1.getNextMIBEntry(s);
	} catch (Exception e) {
	    // do summat
	}
	return null;
    }

    public SNMPVarBindList getMIBEntry(String s) {
	try {
	    return ifv1.getMIBEntry(s);
	} catch (IOException ioe) {
	    // FIXME do summat
	    System.out.println("IOException Retrieving " + s);
	} catch (SNMPBadValueException sbve) {
	    // FIXME do summat
	    System.out.println("SNMPBadValueException Retrieving " + s);
	} catch (SNMPGetException sbve) {
	    // FIXME do summat
	    System.out.println("SNMPGetException Retrieving " + s);
	}
	return null;
    }

    public SnmpObject getValue(String s) {
	SNMPVarBindList newVars = getMIBEntry(s);
	SNMPSequence pair = (SNMPSequence)(newVars.getSNMPObjectAt(0));
	SNMPObjectIdentifier snmpOID =
		    (SNMPObjectIdentifier) pair.getSNMPObjectAt(0);
	return new SnmpObject(snmpOID, pair.getSNMPObjectAt(1));
    }
}
